Reporting bugs and other problems — SnapPy 3.2 documentation

# Reporting bugs and other problems

We very much welcome reports of any difficulties you encounter installing or using SnapPy. While we do significant testing before each release, with so many supported platforms/configurations and only three core developers, we need your help to keep things running smoothly. To report a problem, you may either open a formal issue ticket or write to the developers. As always, it is most helpful if you include the details of your computer’s configuration as well as verbatim copies of any error messages.